@@ -88,7 +88,6 @@ And now doing it directly with a knowledge of what your attachment is, and
 what the correct MIME structure is.
 
   use Email::MIME;
-  use Email::MIME::Creator;
   use Email::Send;
   use IO::All;
   
@@ -128,6 +127,7 @@ Email::Stuff's brevity to your advantage.
 =head2 Custom Alerts
 
   package SMS::Alert;
+  use base 'Email::Stuff';
   
   sub new {
           shift()->SUPER::new(@_)
@@ -171,7 +171,7 @@ use prefork 'File::Type';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '2.100';
+	$VERSION = '2.102';
 }
 
 #####################################################################
@@ -247,7 +247,7 @@ is not for changing emails, just throwing stuff together and sending it.>
 
 sub header {
 	my $self = shift()->_self;
-	$self->{email}->header_set(shift, shift) ? $self : undef;
+	$self->{email}->header_str_set(ucfirst shift, shift) ? $self : undef;
 }
 
 =head2 to $address
@@ -258,7 +258,7 @@ Adds a To: header to the email
 
 sub to {
 	my $self = shift()->_self;
-	$self->{email}->header_set(to => shift) ? $self : undef;
+	$self->{email}->header_str_set(To => shift) ? $self : undef;
 }
 
 =head2 from $address
@@ -269,7 +269,7 @@ Adds (yes ADDS, you only do it once) a From: header to the email
 
 sub from {
 	my $self = shift()->_self;
-	$self->{email}->header_set(from => shift) ? $self : undef;
+	$self->{email}->header_str_set(From => shift) ? $self : undef;
 }
 
 =head2 cc $address
@@ -280,7 +280,7 @@ Adds a Cc: header to the email
 
 sub cc {
 	my $self = shift()->_self;
-	$self->{email}->header_set(cc => shift) ? $self : undef;
+	$self->{email}->header_str_set(Cc => shift) ? $self : undef;
 }
 
 =head2 bcc $address
@@ -291,7 +291,7 @@ Adds a Bcc: header to the email
 
 sub bcc {
 	my $self = shift()->_self;
-	$self->{email}->header_set(bcc => shift) ? $self : undef;
+	$self->{email}->header_str_set(Bcc => shift) ? $self : undef;
 }
 
 =head2 subject $text
@@ -302,7 +302,7 @@ Adds a subject to the email
 
 sub subject {
 	my $self = shift()->_self;
-	$self->{email}->header_set(subject => shift) ? $self : undef;
+	$self->{email}->header_str_set(Subject => shift) ? $self : undef;
 }
 
 #####################################################################
@@ -311,18 +311,21 @@ sub subject {
 =head2 text_body $body [, $header => $value, ... ]
 
 Sets the text body of the email. Unless specified, all the appropriate
-headers are set for you. You may overload any as needed. See
-L<Email::MIME::Creator> for the actual headers to use.
+headers are set for you. You may override any as needed. See
+L<Email::MIME> for the actual headers to use.
+
+If C<$body> is undefined, this method will do nothing.
 
 =cut
 
 sub text_body {
 	my $self = shift()->_self;
-	my $body = defined $_[0] ? shift : return undef;
+	my $body = defined $_[0] ? shift : return $self;
 	my %attr = (
 		# Defaults
 		content_type => 'text/plain',
-		charset      => 'us-ascii',
+		charset      => 'utf-8',
+		encoding     => 'quoted-printable',
 		format       => 'flowed',
 		# Params overwrite them
 		@_,
@@ -331,7 +334,7 @@ sub text_body {
 	# Create the part in the text slot
 	$self->{parts}->[0] = Email::MIME->create(
 		attributes => \%attr,
-		body       => $body,
+		body_str   => $body,
 		);
 
 	$self;
@@ -340,18 +343,21 @@ sub text_body {
 =head2 html_body $body [, $header => $value, ... ]
 
 Set the HTML body of the email. Unless specified, all the appropriate
-headers are set for you. You may overload any as needed. See
-L<Email::MIME::Creator> for the actual headers to use.
+headers are set for you. You may override any as needed. See
+L<Email::MIME> for the actual headers to use.
+
+If C<$body> is undefined, this method will do nothing.
 
 =cut
 
 sub html_body {
 	my $self = shift()->_self;
-	my $body = defined $_[0] ? shift : return undef;
+	my $body = defined $_[0] ? shift : return $self;
 	my %attr = (
 		# Defaults
 		content_type => 'text/html',
-		charset      => 'us-ascii',
+		charset      => 'utf-8',
+		encoding     => 'quoted-printable',
 		# Params overwrite them
 		@_,
 		);
@@ -359,7 +365,7 @@ sub html_body {
 	# Create the part in the HTML slot
 	$self->{parts}->[1] = Email::MIME->create(
 		attributes => \%attr,
-		body       => $body,
+		body_str   => $body,
 		);
 
 	$self;
@@ -542,7 +548,7 @@ sub _transfer_headers {
         foreach my $header_name (@headers_move) {
                 next if _any { $_ eq $header_name } @headers_skip;
                 my @values = $_[0]->header($header_name);
-                $_[1]->header_set( $header_name, @values );
+                $_[1]->header_str_set( $header_name, @values );
         }
 }
 
